@@ -181,9 +181,9 @@ class Cacheable(object):
                 arg = None
                 arg_num += 1
 
-            new_args.append(arg)
+            new_args.append("%s" % arg)
 
-        return tuple(new_args)
+        return '_'.join(new_args)
 
     def _make_version_hash(self):
         return base64.b64encode(uuid.uuid4().bytes)[:6].decode('utf-8')
